.. _exceptions_ref:

Exceptions
==========

The :mod:`aeon.exceptions` module contains classes for exceptions and warnings.

.. automodule:: aeon.exceptions
    :no-members:
    :no-inherited-members:

.. currentmodule:: aeon.exceptions

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    NotEvaluatedError
    NotFittedError
    FitFailedWarning
